==> webform_booking-1.0.1.tar.gz: webform_booking/src/Plugin/WebformElement/WebformBooking.php <==
<?php

namespace Drupal\webform_booking\Plugin\WebformElement;

use Drupal\Core\Form\FormStateInterface;
use Drupal\webform\Plugin\WebformElementBase;
use Drupal\webform\WebformSubmissionInterface;

/**
 * Provides a 'webform_booking' element.
 *
 * @WebformElement(
 *   id = "webform_booking",
 *   label = @Translation("Webform Booking"),
 *   description = @Translation("Provides a webform element for scheduling appointments."),
 *   category = @Translation("Webform Booking"),
 *   states_wrapper = TRUE,
 * )
 */
class WebformBooking extends WebformElementBase {

  /**
   * {@inheritdoc}
   */
  protected function defineDefaultProperties() {
    $properties = parent::defineDefaultProperties() + [
      'title' => '',
      'time_interval' => '',
      'slot_duration' => '',
      'exclusion_dates' => [],
      'excluded_weekdays' => [],
    ];
    unset($properties['markup']);
    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);

    // Hide/Remove default value, form display and markup form elements.
    unset($form['markup'], $form['default']);
    $form['form']['#access'] = FALSE;

    $form['appointment_settings'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Webform Booking Settings'),
    ];

    // Time intervals.
    $form['appointment_settings']['time_interval'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Time Intervals'),
      '#description' => $this->t('Enter time intervals in 24h format. One interval per line. Ex. 08:00|12:00'),
      '#default_value' => $this->getDefaultProperty('time_interval'),
      '#required' => TRUE,
    ];

    // Slot Duration.
    $form['appointment_settings']['slot_duration'] = [
      '#type' => 'number',
      '#title' => $this->t('Slot Duration'),
      '#description' => $this->t('In Minutes'),
      '#default_value' => $this->getDefaultProperty('slot_duration'),
      '#min' => 1,
      '#required' => TRUE,
    ];

    // Exclusion Dates.
    $form['appointment_settings']['exclusion_dates'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Exclusion Dates'),
      '#description' => $this->t('Enter dates in format YYYY-MM-DD or intervals in format YYYY-MM-DD|YYYY-MM-DD, one per line. Ex. 2023-12-25 or 2023-12-25|2024-01-01'),
      '#default_value' => $this->getDefaultProperty('exclusion_dates'),
      '#rows' => 5,
    ];

    // Excluded Weekdays.
    $form['appointment_settings']['excluded_weekdays'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Excluded Weekdays'),
      '#options' => [
        'Sun' => $this->t('Sun'),
        'Mon' => $this->t('Mon'),
        'Tue' => $this->t('Tue'),
        'Wed' => $this->t('Wed'),
        'Thu' => $this->t('Thu'),
        'Fri' => $this->t('Fri'),
        'Sat' => $this->t('Sat'),
      ],
      '#default_value' => $this->getDefaultProperty('excluded_weekdays'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function prepare(array &$element, WebformSubmissionInterface $webform_submission = NULL) {
    $element['#attached']['library'][] = 'webform_booking/webform_booking';
    $element['#attached']['drupalSettings']['webform_booking']['formId'] = $element['#webform'];
    $element['#description'] = '<div id="appointment_wrapper"><div id="calendar-container"></div><div id="slots-container"></div></div>';
    $element['#type'] = 'textfield';
    $element['#attributes'] = ['id' => 'selected-slot'];

    return $element;
  }

}

==> webform_booking-1.0.2.tar.gz: webform_booking/src/Plugin/WebformElement/WebformBooking.php <==
<?php

namespace Drupal\webform_booking\Plugin\WebformElement;

use Drupal\Core\Form\FormStateInterface;
use Drupal\webform\Plugin\WebformElementBase;
use Drupal\webform\WebformSubmissionInterface;

/**
 * Provides a 'webform_booking' element.
 *
 * @WebformElement(
 *   id = "webform_booking",
 *   label = @Translation("Booking"),
 *   description = @Translation("Provides a webform element for scheduling appointments."),
 *   category = @Translation("Booking"),
 *   states_wrapper = TRUE,
 * )
 */
class WebformBooking extends WebformElementBase {

  /**
   * {@inheritdoc}
   */
  protected function defineDefaultProperties() {
    $properties = parent::defineDefaultProperties() + [
      'title' => '',
      'time_interval' => '',
      'slot_duration' => '',
      'seats_slot' => '1',
      'exclusion_dates' => [],
      'excluded_weekdays' => [],
    ];
    unset($properties['markup']);
    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);

    // Hide/Remove default value, form display and markup form elements.
    unset($form['markup'], $form['default']);
    $form['form']['#access'] = FALSE;

    $form['appointment_settings'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Webform Booking Settings'),
    ];

    // Time intervals.
    $form['appointment_settings']['time_interval'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Time Intervals'),
      '#description' => $this->t('Enter time intervals in 24h format. One interval per line. Ex. 08:00|12:00'),
      '#default_value' => $this->getDefaultProperty('time_interval'),
      '#required' => TRUE,
    ];

    // Slot Duration.
    $form['appointment_settings']['slot_duration'] = [
      '#type' => 'number',
      '#title' => $this->t('Slot Duration'),
      '#description' => $this->t('In Minutes'),
      '#default_value' => $this->getDefaultProperty('slot_duration'),
      '#min' => 1,
      '#required' => TRUE,
    ];

    // Seats per slot.
    $form['appointment_settings']['seats_slot'] = [
      '#type' => 'number',
      '#title' => $this->t('Seats Per Slot'),
      '#description' => $this->t('Number of bookings for the same slot'),
      '#default_value' => $this->getDefaultProperty('seats_slot'),
      '#min' => 1,
      '#required' => TRUE,
    ];

    // Exclusion Dates.
    $form['appointment_settings']['exclusion_dates'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Exclusion Dates'),
      '#description' => $this->t('Enter dates in format YYYY-MM-DD or intervals in format YYYY-MM-DD|YYYY-MM-DD, one per line. Ex. 2023-12-25 or 2023-12-25|2024-01-01'),
      '#default_value' => $this->getDefaultProperty('exclusion_dates'),
      '#rows' => 5,
    ];

    // Excluded Weekdays.
    $form['appointment_settings']['excluded_weekdays'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Excluded Weekdays'),
      '#options' => [
        'Mon' => $this->t('Mon'),
        'Tue' => $this->t('Tue'),
        'Wed' => $this->t('Wed'),
        'Thu' => $this->t('Thu'),
        'Fri' => $this->t('Fri'),
        'Sat' => $this->t('Sat'),
        'Sun' => $this->t('Sun'),
      ],
      '#default_value' => $this->getDefaultProperty('excluded_weekdays'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function prepare(array &$element, WebformSubmissionInterface $webform_submission = NULL) {
    $element['#attached']['library'][] = 'webform_booking/webform_booking';
    $element['#attached']['drupalSettings']['webform_booking']['formId'] = $element['#webform'];
    $element['#description'] = '<div id="appointment_wrapper"><div id="calendar-container"></div><div id="slots-container"></div></div>';
    $element['#type'] = 'textfield';
    $element['#attributes'] = ['id' => 'selected-slot'];
    $currentUserRoles = \Drupal::currentUser()->getRoles();
    if (!in_array('administrator', $currentUserRoles)) {
      $element['#attributes']['class'][] = 'hide';
    }

    return $element;
  }

}
